@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
 __title__ = "drf-friendly-errors"
-__version__ = "0.14.4"
-__author__ = "Mrityunjay Saxena"
+__version__ = "0.14.6"
+__author__ = "Tomasz Łaszczuk(Original), Mrityunjay Saxena(This fork)"
 __contact__ = "mrityunjay.saxena@egyanamtech.com"
 __license__ = "MIT"
 
